#[non_exhaustive]pub enum TrackballWheelUnit {
Cpt(f32),
Cps(f32),
}Expand description
TrackballInput setting translating wheel units in coherent scale denominators.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cpt(f32)
Wheel clicks per turn (cpt).
Defaults to 24 cpt, that are 15°=360°/24 per click which agrees with most devices. Some devices have 18 cpt instead, that are 20°=360/18 per click.
You can count the cpt of your device by marking the start of your wheel before rotating it a full turn. Each noticeable step when rotating is called a wheel click, not to be confused with a middle mouse button click.
Cps(f32)
Wheel clicks per second (cps).
Some devices scroll smooth without noticeable steps when rotating. They specify their units in cps (e.g., 1 000 cps). This unit will be translated to the trackball’s angular velocity.
Implementations
Sourceimpl TrackballWheelUnit
impl TrackballWheelUnit
Sourcepub fn denominator(self, w: f32) -> f32
pub fn denominator(self, w: f32) -> f32
Coherent Scale denominator.